@@ -1,7 +1,7 @@
 package App::OrgUtils;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2015-04-03'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010;
 use strict;
@@ -38,7 +38,7 @@ _
 If not set, TZ environment variable will be picked as default.
 
 _
-        #'x.schema.entity' => 'timezone',
+        'x.schema.entity' => 'timezone',
     },
 );
 
@@ -188,7 +188,7 @@ App::OrgUtils - Some utilities for Org documents
 
 =head1 VERSION
 
-This document describes version 0.29 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-04-02.
+This document describes version 0.30 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-04-03.
 
 =head1 DESCRIPTION
 
